docs.rs failed to build rust-rel8-0.2.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
rust-rel8-0.2.2
This is a WIP library attempting to emulate the Haskell Rel8 library.
In essence, it allows you to write queries like so:
// We're injecting the values manually here, but we could as well use Query::each
// to select from a real table.
let demo_users = vec!;
let demo_posts = vec!;
let q =
.order_by;
let rows = q.all.await.unwrap;
assert_eq!
In this query builder, joins are also left to the database to figure out. The
user thinks of each let ... = q.q(...); inside query as being cartesian
produced. The database narrows these cartesian products down to inner or left
joins depending on the where clauses.
I'll add some more examples in the future, but you can also look at the tests in lib.rs.