Module is_nullable

Module is_nullable 

Helper trait that is used to mark if a type could be NULL on the SQL side.

Traits

IsNullable
Helper trait that is used to mark if a type could be NULL on the SQL side.