pub struct A<'inner, 'outer> { /* private fields */ }Expand description
A struct allowing manipulation of an aggregation
Lifetimes
The 'inner lifetime represents the lifetime of the query you are aggregating on.
The 'outer lifetime represents the lifetime of the aggregation query being build.
The two are separate to ensure that any expression in the output table is either used in an aggregation function, or part of a group by clause.
Implementations
Sourceimpl<'inner, 'outer> A<'inner, 'outer>
impl<'inner, 'outer> A<'inner, 'outer>
Sourcepub fn group_by<T: Table<'inner> + ForLifetimeTable>(
&mut self,
expr: T,
) -> T::WithLt<'outer>
pub fn group_by<T: Table<'inner> + ForLifetimeTable>( &mut self, expr: T, ) -> T::WithLt<'outer>
Group the aggregation by the given table.
Sourcepub fn array_agg<T: Table<'inner> + ForLifetimeTable>(
&mut self,
expr: T,
) -> ListTable<T::WithLt<'outer>>
pub fn array_agg<T: Table<'inner> + ForLifetimeTable>( &mut self, expr: T, ) -> ListTable<T::WithLt<'outer>>
Aggregate rows of the given table into an array
Sourcepub fn avg<T: Table<'inner> + ForLifetimeTable>(
&mut self,
expr: T,
) -> T::WithLt<'outer>
pub fn avg<T: Table<'inner> + ForLifetimeTable>( &mut self, expr: T, ) -> T::WithLt<'outer>
Average the values of this table in the group.
Sourcepub fn bit_and<T: Table<'inner> + ForLifetimeTable>(
&mut self,
expr: T,
) -> T::WithLt<'outer>
pub fn bit_and<T: Table<'inner> + ForLifetimeTable>( &mut self, expr: T, ) -> T::WithLt<'outer>
Bit and the values of this table in the group.
Sourcepub fn bit_or<T: Table<'inner> + ForLifetimeTable>(
&mut self,
expr: T,
) -> T::WithLt<'outer>
pub fn bit_or<T: Table<'inner> + ForLifetimeTable>( &mut self, expr: T, ) -> T::WithLt<'outer>
Bit or the values of this table in the group.
Sourcepub fn bit_xor<T: Table<'inner> + ForLifetimeTable>(
&mut self,
expr: T,
) -> T::WithLt<'outer>
pub fn bit_xor<T: Table<'inner> + ForLifetimeTable>( &mut self, expr: T, ) -> T::WithLt<'outer>
Bit xor the values of this table in the group.
Sourcepub fn bool_and<T: Table<'inner> + ForLifetimeTable>(
&mut self,
expr: T,
) -> T::WithLt<'outer>
pub fn bool_and<T: Table<'inner> + ForLifetimeTable>( &mut self, expr: T, ) -> T::WithLt<'outer>
Boolean and the values of this table in the group.
Sourcepub fn bool_or<T: Table<'inner> + ForLifetimeTable>(
&mut self,
expr: T,
) -> T::WithLt<'outer>
pub fn bool_or<T: Table<'inner> + ForLifetimeTable>( &mut self, expr: T, ) -> T::WithLt<'outer>
Boolean or the values of this table in the group.
Sourcepub fn count_star(&mut self) -> Expr<'outer, i32>
pub fn count_star(&mut self) -> Expr<'outer, i32>
Count the number of rows in the group, including nulls.
Sourcepub fn count<T>(&mut self, expr: Expr<'inner, T>) -> Expr<'outer, i32>
pub fn count<T>(&mut self, expr: Expr<'inner, T>) -> Expr<'outer, i32>
Count the number of rows in the group, excluding where the table is null.
Sourcepub fn count_distinct<T>(&mut self, expr: Expr<'inner, T>) -> Expr<'outer, i32>
pub fn count_distinct<T>(&mut self, expr: Expr<'inner, T>) -> Expr<'outer, i32>
Count the distinct number of rows in the group, excluding where the table is null.
Sourcepub fn max<T: Table<'inner> + ForLifetimeTable>(
&mut self,
expr: T,
) -> T::WithLt<'outer>
pub fn max<T: Table<'inner> + ForLifetimeTable>( &mut self, expr: T, ) -> T::WithLt<'outer>
The maximum value of each column of this table in its group.
Sourcepub fn min<T: Table<'inner> + ForLifetimeTable>(
&mut self,
expr: T,
) -> T::WithLt<'outer>
pub fn min<T: Table<'inner> + ForLifetimeTable>( &mut self, expr: T, ) -> T::WithLt<'outer>
The minimum value of each column of this table in its group.
Sourcepub fn sum<T: Table<'inner> + ForLifetimeTable>(
&mut self,
expr: T,
) -> T::WithLt<'outer>
pub fn sum<T: Table<'inner> + ForLifetimeTable>( &mut self, expr: T, ) -> T::WithLt<'outer>
The summation of the values of each column of this table in its group.