pub struct ErasedExpr(/* private fields */);Expand description
A publicly exposed opaque type that is used by Table::visit and Table::visit_mut. Its purpose is to allow you to store Exprs in your types which implement the Table trait.