Expr

Struct Expr 

pub struct Expr<'scope, T> { /* private fields */ }
A type representing an expression in the query, can be passed around on the rust side to wire things up

Implementations

Source

impl<'scope, T> Expr<'scope, T>

pub fn lit(value: T) -> Self
where T: Into<Value>,

Construct a literal value from any value from any value that can be encoded.

pub fn equals(self, other: Self) -> Expr<'scope, bool>

Source

impl<'scope> Expr<'scope, i32>

pub fn add(self, other: Self) -> Self

pub fn nextval(name: &str) -> Self

generate nextval('name'), this must be used within Query::evaluate for it to behave properly.

Example
use rust_rel8::{helper_tables::One, *};

query::<(Expr<i32>, Expr<i32>)>(|q| {
  let id = q.q(Query::evaluate(Expr::nextval("table_id_seq")));
  let v = q.q(Query::values([1, 2, 3].map(|a| One { a })));
  (id, v.a)
});