MaybeTable

Struct MaybeTable 

pub struct MaybeTable<'scope, T> { /* private fields */ }
A table which contains a tag indicating whether a query returned rows. Use Query::optional to construct this.

Implementations

Source

impl<'scope, T: Table<'scope>> MaybeTable<'scope, T>

pub fn project<U, F>(&self, f: F) -> Expr<'scope, Option<U>>
where F: FnOnce(&T) -> Expr<'_, U>,

Project out an expression from the maybe table

pub fn maybe<U: Table<'scope>, F>(self, fallback: U, f: F) -> U
where F: FnOnce(T) -> U,

Test if the table is None, if it is, use the fallback, otherwise call f.