Query

Struct Query 

pub struct Query<T> { /* private fields */ }
A value representing a sql select statement which produces rows of type T.

Implementations

Source

impl<'scope, T> Query<T>
where T: Table<'scope> + ForLifetimeTable,

pub fn aggregate<U>( self, f: impl for<'inner, 'outer> FnOnce(&mut A<'inner, 'outer>, T::WithLt<'inner>) -> U::WithLt<'outer>, ) -> Query<U::WithLt<'scope>>

Enter a context in which A can be used to build aggregations.

The callback f will receive an A, the methods of which can be used to build a table in the 'outer scope.

pub fn many(self) -> Query<ListTable<T>>

Construct a simple list aggregation for this query.

That is, all rows of this query will be aggregated into an array.

pub fn window<U>( self, f: impl for<'inner, 'outer> FnOnce(&mut W<'inner, 'outer>, T::WithLt<'inner>) -> U::WithLt<'outer>, ) -> Query<U::WithLt<'scope>>
where U: ForLifetimeTable + Table<'scope>,

Enter a context in which W can be used to insert expressions using window functions.

The callback f will receive an [F], the methods of which can be used to build a table in the 'outer scope.

pub fn evaluate(table: T) -> Self

Lift a table into a query which ensures side effects happen and are not shared.

pub fn optional(self) -> Query<MaybeTable<'scope, T>>

Transform this query into one which produces rows of either Some<T> or None.

That is, this turns the query into a left join.

pub fn nullable(self) -> Query<NullTable<'scope, T>>

Make this table nullable. Unlike MaybeTable, this isn’t a left join, but instead considers the table null if any of the non-nullable columns are null.

If the table only contains Option<T> then this table cannot distinguish.

pub fn order_by<U, F>(self, f: F) -> Query<T>
where U: Table<'scope>, F: FnOnce(&T) -> (U, Order),

Add an order by clause to the query, the given function should return a table, the query will be ordered by each column of the table.

Source

impl<'scope, T> Query<T>
where T: MapTable<'scope> + TableHKT<Mode = NameMode>, T::InMode<ExprMode>: ForLifetimeTable + Table<'scope>,

pub fn each(schema: &TableSchema<T>) -> Query<T::InMode<ExprMode>>

Given a TableSchema, build a query that selects all columns of every row.

Source

impl<'scope, T: TableHKT<Mode = ValueMode>> Query<T>

pub fn values(vals: impl IntoIterator<Item = T>) -> Query<T::InMode<ExprMode>>
where T: MapTable<'scope>, T::InMode<ExprMode>: ForLifetimeTable + Table<'scope>,

Construct a query yielding the given rows

Source

impl<T: TableLoaderSqlx> Query<T>

pub async fn all(&self, pool: &mut PgConnection) -> Result<Vec<T::Result>>

Load all rows of the query