Module table_modes

Module table_modes 

The modes a table can be in

Enums

EmptyMode
Empty mode, all fields are (). This is used when a mapper doesn’t want to produce a value.
ExprMode
Expr mode, the columns are crate::Exprs.
ExprNullifiedMode
Expr mode, but the value might be null, the columns are crate::Exprs.
NameMode
Name mode, where all columns are [&'static str], representing the column names.
ValueMode
Value mode, representing a table row that has been loaded from the query.
ValueNullifiedMode
Value mode, but the value might be null.