pub trait ModeMapperMut<'scope, SrcMode: TableMode, DestMode: TableMode> {
// Required method
fn map_mode_mut<V>(
&mut self,
src: &mut SrcMode::T<'scope, V>,
) -> DestMode::T<'scope, V>
where V: Value;
}Expand description
This trait allows us to write a mapping function between two column modes.
We use a trait as we need this to work for all types of the type parameter V.
Required Methods
Sourcefn map_mode_mut<V>(
&mut self,
src: &mut SrcMode::T<'scope, V>,
) -> DestMode::T<'scope, V>where
V: Value,
fn map_mode_mut<V>(
&mut self,
src: &mut SrcMode::T<'scope, V>,
) -> DestMode::T<'scope, V>where
V: Value,
Map from SrcMode to DestMode, taking the value as a mutable reference
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.