TableLoaderManySqlx

Trait TableLoaderManySqlx 

pub trait TableLoaderManySqlx: Table + TableLoaderSqlx {
    // Required method
    fn load_many<'a>(
        &self,
        values: &mut impl Iterator<Item = PgValueRef<'a>>,
    ) -> Vec<Self::Result>;
}
Trait allowing loading of many Tables when using sqlx.

Required Methods

fn load_many<'a>( &self, values: &mut impl Iterator<Item = PgValueRef<'a>>, ) -> Vec<Self::Result>

Load the table given an iterator over a vec of row’s values

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> TableLoaderManySqlx for (T₁, T₂, …, Tₙ)

Available on crate feature sqlx only.

This trait is implemented for tuples up to 15 items long.

Source

fn load_many<'a>( &self, values: &mut impl Iterator<Item = PgValueRef<'a>>, ) -> Vec<Self::Result>

Implementors

Source

impl<A, B, C> TableLoaderManySqlx for Three<'static, ExprMode, A, B, C>
where A: Value, B: Value, C: Value,

Source

impl<A, B> TableLoaderManySqlx for Two<'static, ExprMode, A, B>
where A: Value, B: Value,

Source

impl<A> TableLoaderManySqlx for One<'static, ExprMode, A>
where A: Value,

Source

impl<T: Value> TableLoaderManySqlx for Expr<'static, T>

Available on crate feature sqlx only.
Source

impl<T> TableLoaderManySqlx for TableUsingMapper<T>
where T: Table + MapTable<'static> + TableHKT<Mode = ExprMode>, T::InMode<ValueManyMode>: MapTable<'static> + TableHKT<Mode = ValueManyMode>, <<T as TableHKT>::InMode<ValueManyMode> as TableHKT>::InMode<ValueMode>: IsEqual<Self::Result>,

Available on crate feature sqlx only.