Helper trait that is used to mark if a type could be NULL on the SQL side.
Traits
- IsNullable
- Helper trait that is used to mark if a type could be
NULLon the SQL side.
Helper trait that is used to mark if a type could be NULL on the SQL side.
NULL on the SQL side.