pub struct Expr<'scope, T> { /* private fields */ }Expand description
A type representing an expression in the query, can be passed around on the rust side to wire things up
Implementations
Sourceimpl<'scope> Expr<'scope, i32>
impl<'scope> Expr<'scope, i32>
pub fn add(self, other: Self) -> Self
Sourcepub fn nextval(name: &str) -> Self
pub fn nextval(name: &str) -> Self
generate nextval('name'), this must be used within Query::evaluate
for it to behave properly.
Example
use rust_rel8::{helper_tables::One, *};
query::<(Expr<i32>, Expr<i32>)>(|q| {
let id = q.q(Query::evaluate(Expr::nextval("table_id_seq")));
let v = q.q(Query::values([1, 2, 3].map(|a| One { a })));
(id, v.a)
});Trait Implementations
Sourceimpl<T> ShortenLifetime for Expr<'static, T>
impl<T> ShortenLifetime for Expr<'static, T>
type Shortened<'small> = Expr<'small, T> where Self: 'small
Sourcefn shorten_lifetime<'small, 'large: 'small>(self) -> Self::Shortened<'small>where
Self: 'large,
fn shorten_lifetime<'small, 'large: 'small>(self) -> Self::Shortened<'small>where
Self: 'large,
Shorten a lifetime, normally rust does this automatically, but if
the lifetime is invariant due to being used in a Gat or trait, we
need to do it manually. Read more
Sourceimpl<'scope, T> Table<'scope> for Expr<'scope, T>
impl<'scope, T> Table<'scope> for Expr<'scope, T>
Sourceimpl<T: for<'r> Decode<'r, Any>> TableLoaderSqlx for Expr<'static, T>
Available on crate feature sqlx only.
impl<T: for<'r> Decode<'r, Any>> TableLoaderSqlx for Expr<'static, T>
Available on crate feature
sqlx only.Sourcefn load<'a>(
&self,
values: &mut impl Iterator<Item = AnyValueRef<'a>>,
) -> Self::Result
fn load<'a>( &self, values: &mut impl Iterator<Item = AnyValueRef<'a>>, ) -> Self::Result
Load the table given an iterator over a row’s values
Sourcefn skip<'a>(&self, values: &mut impl Iterator<Item = AnyValueRef<'a>>)
fn skip<'a>(&self, values: &mut impl Iterator<Item = AnyValueRef<'a>>)
discard N columns from the iterator ofer a row
This is used when this value was discarded by a MaybeTable.