pub struct Query<T> { /* private fields */ }Expand description
A value representing a sql select statement which produces rows of type T.
Implementations
Sourceimpl<'scope, T> Query<T>where
T: Table<'scope> + ForLifetimeTable,
impl<'scope, T> Query<T>where
T: Table<'scope> + ForLifetimeTable,
Sourcepub fn aggregate<U>(
self,
f: impl for<'inner, 'outer> FnOnce(&mut A<'inner, 'outer>, T::WithLt<'inner>) -> U::WithLt<'outer>,
) -> Query<U::WithLt<'scope>>where
U: ForLifetimeTable,
pub fn aggregate<U>(
self,
f: impl for<'inner, 'outer> FnOnce(&mut A<'inner, 'outer>, T::WithLt<'inner>) -> U::WithLt<'outer>,
) -> Query<U::WithLt<'scope>>where
U: ForLifetimeTable,
Sourcepub fn many(self) -> Query<ListTable<T>>
pub fn many(self) -> Query<ListTable<T>>
Construct a simple list aggregation for this query.
That is, all rows of this query will be aggregated into an array.
Sourcepub fn window<U>(
self,
f: impl for<'inner, 'outer> FnOnce(&mut W<'inner, 'outer>, T::WithLt<'inner>) -> U::WithLt<'outer>,
) -> Query<U::WithLt<'scope>>where
U: ForLifetimeTable + Table<'scope>,
pub fn window<U>(
self,
f: impl for<'inner, 'outer> FnOnce(&mut W<'inner, 'outer>, T::WithLt<'inner>) -> U::WithLt<'outer>,
) -> Query<U::WithLt<'scope>>where
U: ForLifetimeTable + Table<'scope>,
Enter a context in which W can be used to insert expressions using window functions.
The callback f will receive an [F], the methods of which can be used
to build a table in the 'outer scope.
Sourcepub fn evaluate(table: T) -> Self
pub fn evaluate(table: T) -> Self
Lift a table into a query which ensures side effects happen and are not shared.
Sourcepub fn optional(self) -> Query<MaybeTable<'scope, T>>
pub fn optional(self) -> Query<MaybeTable<'scope, T>>
Sourcepub fn nullable(self) -> Query<NullTable<'scope, T>>
pub fn nullable(self) -> Query<NullTable<'scope, T>>
Make this table nullable. Unlike MaybeTable, this isn’t a left join, but instead considers the table null if any of the non-nullable columns are null.
If the table only contains Option<T> then this table cannot distinguish.
Sourceimpl<'scope, T> Query<T>
impl<'scope, T> Query<T>
Sourcepub fn each(schema: &TableSchema<T>) -> Query<T::InMode<ExprMode>>
pub fn each(schema: &TableSchema<T>) -> Query<T::InMode<ExprMode>>
Given a TableSchema, build a query that selects all columns of every row.
Sourceimpl<T: TableLoaderSqlx> Query<T>
impl<T: TableLoaderSqlx> Query<T>