The modes a table can be in
Enums
- Empty
Mode - Empty mode, all fields are
(). This is used when a mapper doesn’t want to produce a value. - Expr
Mode - Expr mode, the columns are crate::Exprs.
- Expr
Nullified Mode - Expr mode, but the value might be null, the columns are crate::Exprs.
- Name
Mode - Name mode, where all columns are [
&'static str], representing the column names. - Value
Mode - Value mode, representing a table row that has been loaded from the query.
- Value
Nullified Mode - Value mode, but the value might be null.