pub trait ForLifetimeTable {
type WithLt<'lt>: ForLifetimeTable + Table<'lt> + Sized;
// Required method
fn with_lt<'lt>(self, marker: &mut WithLtMarker) -> Self::WithLt<'lt>;
}Expand description
A helper trait that allows us to talk about a Table with different
lifetimes. Conceptually it is a type level function of lt -> T where T: Table<'lt>.
If you implement Table on your type, you must also implement ForLifetimeTable.
Required Associated Types
Sourcetype WithLt<'lt>: ForLifetimeTable + Table<'lt> + Sized
type WithLt<'lt>: ForLifetimeTable + Table<'lt> + Sized
Substitute the lifetime of this table with 'lt.
Required Methods
Sourcefn with_lt<'lt>(self, marker: &mut WithLtMarker) -> Self::WithLt<'lt>
fn with_lt<'lt>(self, marker: &mut WithLtMarker) -> Self::WithLt<'lt>
Coerce the lifetime of this table. This is used internally by the library.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl<T> ForLifetimeTable for (T₁, T₂, …, Tₙ)where
T: ForLifetimeTable,
This trait is implemented for tuples up to 15 items long.
impl<T> ForLifetimeTable for (T₁, T₂, …, Tₙ)where
T: ForLifetimeTable,
This trait is implemented for tuples up to 15 items long.