pub trait ForLifetimeTable: Sized {
type Of<'lt>: Table<'lt> + Sized
where Self: 'lt;
}Expand description
A helper trait that allows us to talk about a Table with different
lifetimes. Conceptually it is a type level function of lt -> T where T: Table<'lt>.
If you implement Table on your type, you must also implement ForLifetimeTable.
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.