pub trait TableLoaderSqlx: Table<'static> {
// Required methods
fn load<'a>(
&self,
values: &mut impl Iterator<Item = PgValueRef<'a>>,
) -> Self::Result;
fn skip<'a>(&self, values: &mut impl Iterator<Item = PgValueRef<'a>>);
}Expand description
Trait allowing loading of Tables when using sqlx.
Required Methods
Sourcefn load<'a>(
&self,
values: &mut impl Iterator<Item = PgValueRef<'a>>,
) -> Self::Result
fn load<'a>( &self, values: &mut impl Iterator<Item = PgValueRef<'a>>, ) -> Self::Result
Load the table given an iterator over a row’s values
Sourcefn skip<'a>(&self, values: &mut impl Iterator<Item = PgValueRef<'a>>)
fn skip<'a>(&self, values: &mut impl Iterator<Item = PgValueRef<'a>>)
discard N columns from the iterator ofer a row This is used when this value was discarded by a MaybeTable.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl<T> TableLoaderSqlx for (T₁, T₂, …, Tₙ)where
T: TableLoaderSqlx,
Available on crate feature sqlx only.This trait is implemented for tuples up to 15 items long.
impl<T> TableLoaderSqlx for (T₁, T₂, …, Tₙ)where
T: TableLoaderSqlx,
Available on crate feature
sqlx only.This trait is implemented for tuples up to 15 items long.
Implementors
impl<A> TableLoaderSqlx for One<'static, ExprMode, A>where
A: Value,
impl<A, B> TableLoaderSqlx for Two<'static, ExprMode, A, B>
impl<A, B, C> TableLoaderSqlx for Three<'static, ExprMode, A, B, C>
impl<T> TableLoaderSqlx for TableUsingMapper<T>
Available on crate feature
sqlx only.impl<T: TableLoaderManySqlx> TableLoaderSqlx for ListTable<T>
Available on crate feature
sqlx only.impl<T: TableLoaderSqlx> TableLoaderSqlx for MaybeTable<'static, T>
Available on crate feature
sqlx only.impl<T: TableLoaderSqlx> TableLoaderSqlx for NullTable<'static, T>
Available on crate feature
sqlx only.impl<T: Value> TableLoaderSqlx for Expr<'static, T>
Available on crate feature
sqlx only.