TableLoaderSqlx

Trait TableLoaderSqlx 

pub trait TableLoaderSqlx: Table<'static> {
    // Required methods
    fn load<'a>(
        &self,
        values: &mut impl Iterator<Item = AnyValueRef<'a>>,
    ) -> Self::Result;
    fn skip<'a>(&self, values: &mut impl Iterator<Item = AnyValueRef<'a>>);
}

Required Methods

fn load<'a>( &self, values: &mut impl Iterator<Item = AnyValueRef<'a>>, ) -> Self::Result

Load the table given an iterator over a row’s values

fn skip<'a>(&self, values: &mut impl Iterator<Item = AnyValueRef<'a>>)

discard N columns from the iterator ofer a row This is used when this value was discarded by a MaybeTable.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<A: TableLoaderSqlx> TableLoaderSqlx for (A,)

Available on crate feature sqlx only.
Source

fn load<'a>( &self, values: &mut impl Iterator<Item = AnyValueRef<'a>>, ) -> Self::Result

Source

fn skip<'a>(&self, values: &mut impl Iterator<Item = AnyValueRef<'a>>)

Source

impl<A: TableLoaderSqlx, B: TableLoaderSqlx> TableLoaderSqlx for (A, B)

Available on crate feature sqlx only.
Source

fn load<'a>( &self, values: &mut impl Iterator<Item = AnyValueRef<'a>>, ) -> Self::Result

Source

fn skip<'a>(&self, values: &mut impl Iterator<Item = AnyValueRef<'a>>)

Source

impl<A: TableLoaderSqlx, B: TableLoaderSqlx, C: TableLoaderSqlx> TableLoaderSqlx for (A, B, C)

Available on crate feature sqlx only.
Source

fn load<'a>( &self, values: &mut impl Iterator<Item = AnyValueRef<'a>>, ) -> Self::Result

Source

fn skip<'a>(&self, values: &mut impl Iterator<Item = AnyValueRef<'a>>)

Implementors

Source

impl<A> TableLoaderSqlx for One<'static, ExprMode, A>
where A: Value,

Source

impl<A, B> TableLoaderSqlx for Two<'static, ExprMode, A, B>
where A: Value, B: Value,

Source

impl<A, B, C> TableLoaderSqlx for Three<'static, ExprMode, A, B, C>
where A: Value, B: Value, C: Value,

Source

impl<T> TableLoaderSqlx for TableUsingMapper<T>
where T: Table<'static> + MapTable<'static> + TableHKT<Mode = ExprMode>, T::Of<ExprNullifiedMode>: Table<'static>,

Available on crate feature sqlx only.
Source

impl<T: TableLoaderSqlx> TableLoaderSqlx for MaybeTable<'static, T>

Available on crate feature sqlx only.
Source

impl<T: for<'r> Decode<'r, Any>> TableLoaderSqlx for Expr<'static, T>

Available on crate feature sqlx only.