pub trait TableLoaderSqlx: Table<'static> {
// Required methods
fn load<'a>(
&self,
values: &mut impl Iterator<Item = AnyValueRef<'a>>,
) -> Self::Result;
fn skip<'a>(&self, values: &mut impl Iterator<Item = AnyValueRef<'a>>);
}Required Methods
Sourcefn load<'a>(
&self,
values: &mut impl Iterator<Item = AnyValueRef<'a>>,
) -> Self::Result
fn load<'a>( &self, values: &mut impl Iterator<Item = AnyValueRef<'a>>, ) -> Self::Result
Load the table given an iterator over a row’s values
Sourcefn skip<'a>(&self, values: &mut impl Iterator<Item = AnyValueRef<'a>>)
fn skip<'a>(&self, values: &mut impl Iterator<Item = AnyValueRef<'a>>)
discard N columns from the iterator ofer a row This is used when this value was discarded by a MaybeTable.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl<A: TableLoaderSqlx> TableLoaderSqlx for (A,)
Available on crate feature sqlx only.
impl<A: TableLoaderSqlx> TableLoaderSqlx for (A,)
Available on crate feature
sqlx only.Sourceimpl<A: TableLoaderSqlx, B: TableLoaderSqlx> TableLoaderSqlx for (A, B)
Available on crate feature sqlx only.
impl<A: TableLoaderSqlx, B: TableLoaderSqlx> TableLoaderSqlx for (A, B)
Available on crate feature
sqlx only.Sourceimpl<A: TableLoaderSqlx, B: TableLoaderSqlx, C: TableLoaderSqlx> TableLoaderSqlx for (A, B, C)
Available on crate feature sqlx only.
impl<A: TableLoaderSqlx, B: TableLoaderSqlx, C: TableLoaderSqlx> TableLoaderSqlx for (A, B, C)
Available on crate feature
sqlx only.Implementors
impl<A> TableLoaderSqlx for One<'static, ExprMode, A>where
A: Value,
impl<A, B> TableLoaderSqlx for Two<'static, ExprMode, A, B>
impl<A, B, C> TableLoaderSqlx for Three<'static, ExprMode, A, B, C>
impl<T> TableLoaderSqlx for TableUsingMapper<T>
Available on crate feature
sqlx only.impl<T: TableLoaderSqlx> TableLoaderSqlx for MaybeTable<'static, T>
Available on crate feature
sqlx only.impl<T: for<'r> Decode<'r, Any>> TableLoaderSqlx for Expr<'static, T>
Available on crate feature
sqlx only.