pub trait TableMode {
type T<'scope, V>;
}Expand description
Table modes, this trait is used to switch the types of a rust structs fields.
You should use it in table struct like so:
use rust_rel8::*;
struct MyTable<'scope, Mode: TableMode> {
id: Mode::T<'scope, i32>,
name: Mode::T<'scope, String>,
age: Mode::T<'scope, i32>,
}Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.