Value

Trait Value 

pub trait Value: Into<Value> + SqlxValueIfEnabled { }
This trait represents values we know to encode and decode from their database type.

Depending on features, this will have supertraits of the encode/decode traits of the backends.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T> Value for T
where T: Into<Value> + Value,